Documentation
¶
Overview ¶
Package xf86dri is the X client API for the XFree86-DRI extension.
Index ¶
- func DrmClipRectListBytes(buf []byte, list []DrmClipRect) int
- func DrmClipRectRead(buf []byte, v *DrmClipRect) int
- func DrmClipRectReadList(buf []byte, dest []DrmClipRect) int
- func Init(c *xgb.Conn) error
- type AuthConnectionCookie
- type AuthConnectionReply
- type CloseConnectionCookie
- type CreateContextCookie
- type CreateContextReply
- type CreateDrawableCookie
- type CreateDrawableReply
- type DestroyContextCookie
- type DestroyDrawableCookie
- type DrmClipRect
- type GetClientDriverNameCookie
- type GetClientDriverNameReply
- type GetDeviceInfoCookie
- type GetDeviceInfoReply
- type GetDrawableInfoCookie
- type GetDrawableInfoReply
- type OpenConnectionCookie
- type OpenConnectionReply
- type QueryDirectRenderingCapableCookie
- type QueryDirectRenderingCapableReply
- type QueryVersionCookie
- type QueryVersionReply
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DrmClipRectListBytes ¶
func DrmClipRectListBytes(buf []byte, list []DrmClipRect) int
DrmClipRectListBytes writes a list of DrmClipRect values to a byte slice.
func DrmClipRectRead ¶
func DrmClipRectRead(buf []byte, v *DrmClipRect) int
DrmClipRectRead reads a byte slice into a DrmClipRect value.
func DrmClipRectReadList ¶
func DrmClipRectReadList(buf []byte, dest []DrmClipRect) int
DrmClipRectReadList reads a byte slice into a list of DrmClipRect values.
Types ¶
type AuthConnectionCookie ¶
AuthConnectionCookie is a cookie used only for AuthConnection requests.
func AuthConnection ¶
func AuthConnection(c *xgb.Conn, Screen uint32, Magic uint32) AuthConnectionCookie
AuthConnection sends a checked request. If an error occurs, it will be returned with the reply by calling AuthConnectionCookie.Reply()
func AuthConnectionUnchecked ¶
func AuthConnectionUnchecked(c *xgb.Conn, Screen uint32, Magic uint32) AuthConnectionCookie
AuthConnectionUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (AuthConnectionCookie) Reply ¶
func (cook AuthConnectionCookie) Reply() (*AuthConnectionReply, error)
Reply blocks and returns the reply data for a AuthConnection request.
type AuthConnectionReply ¶
type AuthConnectionReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
Authenticated uint32
}
AuthConnectionReply represents the data returned from a AuthConnection request.
type CloseConnectionCookie ¶
CloseConnectionCookie is a cookie used only for CloseConnection requests.
func CloseConnection ¶
func CloseConnection(c *xgb.Conn, Screen uint32) CloseConnectionCookie
CloseConnection sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func CloseConnectionChecked ¶
func CloseConnectionChecked(c *xgb.Conn, Screen uint32) CloseConnectionCookie
CloseConnectionChecked sends a checked request. If an error occurs, it can be retrieved using CloseConnectionCookie.Check()
func (CloseConnectionCookie) Check ¶
func (cook CloseConnectionCookie) Check() error
Check returns an error if one occurred for checked requests that are not expecting a reply. This cannot be called for requests expecting a reply, nor for unchecked requests.
type CreateContextCookie ¶
CreateContextCookie is a cookie used only for CreateContext requests.
func CreateContext ¶
CreateContext sends a checked request. If an error occurs, it will be returned with the reply by calling CreateContextCookie.Reply()
func CreateContextUnchecked ¶
func CreateContextUnchecked(c *xgb.Conn, Screen uint32, Visual uint32, Context uint32) CreateContextCookie
CreateContextUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (CreateContextCookie) Reply ¶
func (cook CreateContextCookie) Reply() (*CreateContextReply, error)
Reply blocks and returns the reply data for a CreateContext request.
type CreateContextReply ¶
type CreateContextReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
HwContext uint32
}
CreateContextReply represents the data returned from a CreateContext request.
type CreateDrawableCookie ¶
CreateDrawableCookie is a cookie used only for CreateDrawable requests.
func CreateDrawable ¶
func CreateDrawable(c *xgb.Conn, Screen uint32, Drawable uint32) CreateDrawableCookie
CreateDrawable sends a checked request. If an error occurs, it will be returned with the reply by calling CreateDrawableCookie.Reply()
func CreateDrawableUnchecked ¶
func CreateDrawableUnchecked(c *xgb.Conn, Screen uint32, Drawable uint32) CreateDrawableCookie
CreateDrawableUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (CreateDrawableCookie) Reply ¶
func (cook CreateDrawableCookie) Reply() (*CreateDrawableReply, error)
Reply blocks and returns the reply data for a CreateDrawable request.
type CreateDrawableReply ¶
type CreateDrawableReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
HwDrawableHandle uint32
}
CreateDrawableReply represents the data returned from a CreateDrawable request.
type DestroyContextCookie ¶
DestroyContextCookie is a cookie used only for DestroyContext requests.
func DestroyContext ¶
func DestroyContext(c *xgb.Conn, Screen uint32, Context uint32) DestroyContextCookie
DestroyContext sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func DestroyContextChecked ¶
func DestroyContextChecked(c *xgb.Conn, Screen uint32, Context uint32) DestroyContextCookie
DestroyContextChecked sends a checked request. If an error occurs, it can be retrieved using DestroyContextCookie.Check()
func (DestroyContextCookie) Check ¶
func (cook DestroyContextCookie) Check() error
Check returns an error if one occurred for checked requests that are not expecting a reply. This cannot be called for requests expecting a reply, nor for unchecked requests.
type DestroyDrawableCookie ¶
DestroyDrawableCookie is a cookie used only for DestroyDrawable requests.
func DestroyDrawable ¶
func DestroyDrawable(c *xgb.Conn, Screen uint32, Drawable uint32) DestroyDrawableCookie
DestroyDrawable sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func DestroyDrawableChecked ¶
func DestroyDrawableChecked(c *xgb.Conn, Screen uint32, Drawable uint32) DestroyDrawableCookie
DestroyDrawableChecked sends a checked request. If an error occurs, it can be retrieved using DestroyDrawableCookie.Check()
func (DestroyDrawableCookie) Check ¶
func (cook DestroyDrawableCookie) Check() error
Check returns an error if one occurred for checked requests that are not expecting a reply. This cannot be called for requests expecting a reply, nor for unchecked requests.
type DrmClipRect ¶
func (DrmClipRect) Bytes ¶
func (v DrmClipRect) Bytes() []byte
Bytes writes a DrmClipRect value to a byte slice.
type GetClientDriverNameCookie ¶
GetClientDriverNameCookie is a cookie used only for GetClientDriverName requests.
func GetClientDriverName ¶
func GetClientDriverName(c *xgb.Conn, Screen uint32) GetClientDriverNameCookie
GetClientDriverName sends a checked request. If an error occurs, it will be returned with the reply by calling GetClientDriverNameCookie.Reply()
func GetClientDriverNameUnchecked ¶
func GetClientDriverNameUnchecked(c *xgb.Conn, Screen uint32) GetClientDriverNameCookie
GetClientDriverNameUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (GetClientDriverNameCookie) Reply ¶
func (cook GetClientDriverNameCookie) Reply() (*GetClientDriverNameReply, error)
Reply blocks and returns the reply data for a GetClientDriverName request.
type GetClientDriverNameReply ¶
type GetClientDriverNameReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
ClientDriverMajorVersion uint32
ClientDriverMinorVersion uint32
ClientDriverPatchVersion uint32
ClientDriverNameLen uint32
// padding: 8 bytes
ClientDriverName string // size: xgb.Pad((int(ClientDriverNameLen) * 1))
}
GetClientDriverNameReply represents the data returned from a GetClientDriverName request.
type GetDeviceInfoCookie ¶
GetDeviceInfoCookie is a cookie used only for GetDeviceInfo requests.
func GetDeviceInfo ¶
func GetDeviceInfo(c *xgb.Conn, Screen uint32) GetDeviceInfoCookie
GetDeviceInfo sends a checked request. If an error occurs, it will be returned with the reply by calling GetDeviceInfoCookie.Reply()
func GetDeviceInfoUnchecked ¶
func GetDeviceInfoUnchecked(c *xgb.Conn, Screen uint32) GetDeviceInfoCookie
GetDeviceInfoUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (GetDeviceInfoCookie) Reply ¶
func (cook GetDeviceInfoCookie) Reply() (*GetDeviceInfoReply, error)
Reply blocks and returns the reply data for a GetDeviceInfo request.
type GetDeviceInfoReply ¶
type GetDeviceInfoReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
FramebufferHandleLow uint32
FramebufferHandleHigh uint32
FramebufferOriginOffset uint32
FramebufferSize uint32
FramebufferStride uint32
DevicePrivateSize uint32
DevicePrivate []uint32 // size: xgb.Pad((int(DevicePrivateSize) * 4))
}
GetDeviceInfoReply represents the data returned from a GetDeviceInfo request.
type GetDrawableInfoCookie ¶
GetDrawableInfoCookie is a cookie used only for GetDrawableInfo requests.
func GetDrawableInfo ¶
func GetDrawableInfo(c *xgb.Conn, Screen uint32, Drawable uint32) GetDrawableInfoCookie
GetDrawableInfo sends a checked request. If an error occurs, it will be returned with the reply by calling GetDrawableInfoCookie.Reply()
func GetDrawableInfoUnchecked ¶
func GetDrawableInfoUnchecked(c *xgb.Conn, Screen uint32, Drawable uint32) GetDrawableInfoCookie
GetDrawableInfoUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (GetDrawableInfoCookie) Reply ¶
func (cook GetDrawableInfoCookie) Reply() (*GetDrawableInfoReply, error)
Reply blocks and returns the reply data for a GetDrawableInfo request.
type GetDrawableInfoReply ¶
type GetDrawableInfoReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
DrawableTableIndex uint32
DrawableTableStamp uint32
DrawableOriginX int16
DrawableOriginY int16
DrawableSizeW int16
DrawableSizeH int16
NumClipRects uint32
BackX int16
BackY int16
NumBackClipRects uint32
ClipRects []DrmClipRect // size: xgb.Pad((int(NumClipRects) * 8))
// alignment gap to multiple of 4
BackClipRects []DrmClipRect // size: xgb.Pad((int(NumBackClipRects) * 8))
}
GetDrawableInfoReply represents the data returned from a GetDrawableInfo request.
type OpenConnectionCookie ¶
OpenConnectionCookie is a cookie used only for OpenConnection requests.
func OpenConnection ¶
func OpenConnection(c *xgb.Conn, Screen uint32) OpenConnectionCookie
OpenConnection sends a checked request. If an error occurs, it will be returned with the reply by calling OpenConnectionCookie.Reply()
func OpenConnectionUnchecked ¶
func OpenConnectionUnchecked(c *xgb.Conn, Screen uint32) OpenConnectionCookie
OpenConnectionUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (OpenConnectionCookie) Reply ¶
func (cook OpenConnectionCookie) Reply() (*OpenConnectionReply, error)
Reply blocks and returns the reply data for a OpenConnection request.
type OpenConnectionReply ¶
type OpenConnectionReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
SareaHandleLow uint32
SareaHandleHigh uint32
BusIdLen uint32
// padding: 12 bytes
BusId string // size: xgb.Pad((int(BusIdLen) * 1))
}
OpenConnectionReply represents the data returned from a OpenConnection request.
type QueryDirectRenderingCapableCookie ¶
QueryDirectRenderingCapableCookie is a cookie used only for QueryDirectRenderingCapable requests.
func QueryDirectRenderingCapable ¶
func QueryDirectRenderingCapable(c *xgb.Conn, Screen uint32) QueryDirectRenderingCapableCookie
QueryDirectRenderingCapable sends a checked request. If an error occurs, it will be returned with the reply by calling QueryDirectRenderingCapableCookie.Reply()
func QueryDirectRenderingCapableUnchecked ¶
func QueryDirectRenderingCapableUnchecked(c *xgb.Conn, Screen uint32) QueryDirectRenderingCapableCookie
QueryDirectRenderingCapableUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (QueryDirectRenderingCapableCookie) Reply ¶
func (cook QueryDirectRenderingCapableCookie) Reply() (*QueryDirectRenderingCapableReply, error)
Reply blocks and returns the reply data for a QueryDirectRenderingCapable request.
type QueryDirectRenderingCapableReply ¶
type QueryDirectRenderingCapableReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
IsCapable bool
}
QueryDirectRenderingCapableReply represents the data returned from a QueryDirectRenderingCapable request.
type QueryVersionCookie ¶
QueryVersionCookie is a cookie used only for QueryVersion requests.
func QueryVersion ¶
func QueryVersion(c *xgb.Conn) QueryVersionCookie
QueryVersion sends a checked request. If an error occurs, it will be returned with the reply by calling QueryVersionCookie.Reply()
func QueryVersionUnchecked ¶
func QueryVersionUnchecked(c *xgb.Conn) QueryVersionCookie
QueryVersionUnchecked sends an unchecked request. If an error occurs, it can only be retrieved using xgb.WaitForEvent or xgb.PollForEvent.
func (QueryVersionCookie) Reply ¶
func (cook QueryVersionCookie) Reply() (*QueryVersionReply, error)
Reply blocks and returns the reply data for a QueryVersion request.
type QueryVersionReply ¶
type QueryVersionReply struct {
Sequence uint16 // sequence number of the request for this reply
Length uint32 // number of bytes in this reply
// padding: 1 bytes
DriMajorVersion uint16
DriMinorVersion uint16
DriMinorPatch uint32
}
QueryVersionReply represents the data returned from a QueryVersion request.